@@ -16,7 +16,7 @@ module Msf::DBManager::Cred
       query = query.includes(logins: [ :service, { service: :host } ])
 
       if opts[:type].present?
-        query = query.where('"metasploit_credential_privates"."type" = ?', opts[:type])
+        query = query.where('"metasploit_credential_privates"."type" = ?', opts[:type].to_s)
       end
 
       if opts[:jtr_format].present?
