@@ -51,6 +51,11 @@ class MetasploitModule < Msf::Exploit::Local
               ]
             }
           },
+          'Notes' => {
+            'Reliability' => UNKNOWN_RELIABILITY,
+            'Stability' => UNKNOWN_STABILITY,
+            'SideEffects' => UNKNOWN_SIDE_EFFECTS
+          },
         }
       )
     )
