@@ -52,7 +52,12 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'Privileged' => true,
         'DisclosureDate' => '2014-02-03',
-        'DefaultTarget' => 0
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
       )
     )
 
