@@ -49,6 +49,11 @@ class MetasploitModule < Msf::Exploit::Remote
               stdapi_fs_delete_file
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
