@@ -3,8 +3,6 @@ require 'acceptance_spec_helper'
 RSpec.describe 'MySQL sessions and MySQL modules' do
   include_context 'wait_for_expect'
 
-  RHOST_REGEX = /\d+\.\d+\.\d+\.\d+:\d+/
-
   tests = {
     mysql: {
       target: {
@@ -49,7 +47,7 @@ RSpec.describe 'MySQL sessions and MySQL modules' do
           lines: {
             all: {
               required: [
-                /#{RHOST_REGEX} is running MySQL \d+.\d+.*/
+                /\d+\.\d+\.\d+\.\d+:\d+ is running MySQL \d+.\d+.*/
               ]
             },
           }
@@ -86,7 +84,7 @@ RSpec.describe 'MySQL sessions and MySQL modules' do
 
   allure_test_environment = AllureRspec.configuration.environment_properties
 
-  let_it_be(:current_platform) { Acceptance::Meterpreter::current_platform }
+  let_it_be(:current_platform) { Acceptance::Session::current_platform }
 
   # Driver instance, keeps track of all open processes/payloads/etc, so they can be closed cleanly
   let_it_be(:driver) do
@@ -161,7 +159,7 @@ RSpec.describe 'MySQL sessions and MySQL modules' do
         end
 
         validated_lines.each do |test_line|
-          test_line = Acceptance::Meterpreter.uncolorize(test_line)
+          test_line = Acceptance::Session.uncolorize(test_line)
           expect(test_line).to_not include('FAILED', '[-] FAILED', '[-] Exception', '[-] '), "Unexpected error: #{test_line}"
         end
 
@@ -250,12 +248,12 @@ RSpec.describe 'MySQL sessions and MySQL modules' do
   tests.each do |runtime_name, test_config|
     runtime_name = "#{runtime_name}#{ENV.fetch('RUNTIME_VERSION', '')}"
 
-    describe "#{Acceptance::Meterpreter.current_platform}/#{runtime_name}", focus: test_config[:focus] do
+    describe "#{Acceptance::Session.current_platform}/#{runtime_name}", focus: test_config[:focus] do
       test_config[:module_tests].each do |module_test|
         describe(
           module_test[:name],
           if: (
-            Acceptance::Meterpreter.supported_platform?(module_test)
+            Acceptance::Session.supported_platform?(module_test)
           )
         ) do
           let(:target) { Acceptance::Target.new(test_config[:target]) }
@@ -318,7 +316,7 @@ RSpec.describe 'MySQL sessions and MySQL modules' do
 
           context "when targeting a session", if: module_test[:targets].include?(:session) do
             it(
-              "#{Acceptance::Meterpreter.current_platform}/#{runtime_name} session opens and passes the #{module_test[:name].inspect} tests"
+              "#{Acceptance::Session.current_platform}/#{runtime_name} session opens and passes the #{module_test[:name].inspect} tests"
             ) do
               with_test_harness(module_test) do |replication_commands|
                 # Ensure we have a valid session id; We intentionally omit this from a `before(:each)` to ensure the allure attachments are generated if the session dies
@@ -343,7 +341,7 @@ RSpec.describe 'MySQL sessions and MySQL modules' do
 
           context "when targeting an rhost", if: module_test[:targets].include?(:rhost) do
             it(
-              "#{Acceptance::Meterpreter.current_platform}/#{runtime_name} rhost opens and passes the #{module_test[:name].inspect} tests"
+              "#{Acceptance::Session.current_platform}/#{runtime_name} rhost opens and passes the #{module_test[:name].inspect} tests"
             ) do
               with_test_harness(module_test) do |replication_commands|
                 use_module = "use #{module_test[:name]}"
